@@ -40,6 +40,42 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
+/**
+ * GOFileFormatLevel:
+ * @GO_FILE_FL_NONE: no name assigned, won't happen.
+ * @GO_FILE_FL_WRITE_ONLY: PostScript etc, won't be remembered.
+ * @GO_FILE_FL_NEW: Wb just created.
+ * @GO_FILE_FL_MANUAL: Save gets punted to save as.
+ * @GO_FILE_FL_MANUAL_REMEMBER: Ditto, but remember in history.
+ * @GO_FILE_FL_AUTO: Save will save to this filename.
+ * @GO_FILE_FL_LAST: last value, won't happen.
+ **/
+
+/**
+ * GOFileSaveScope:
+ * @GO_FILE_SAVE_WORKBOOK: save the whole file.
+ * @GO_FILE_SAVE_SHEET: save only current page.
+ * @GO_FILE_SAVE_RANGE: save only a selected range.
+ * @GO_FILE_SAVE_LAST: last value, won't happen.
+ **/
+
+/**
+ * GOFileProbeLevel:
+ * @GO_FILE_PROBE_FILE_NAME: test only file name, don't read file contents.
+ * @GO_FILE_PROBE_CONTENT: read the whole file if it's necessary.
+ * @GO_FILE_PROBE_LAST: last value, won't happen.
+ **/
+
+/**
+ * GOFileOpenerClass:
+ * @parent_class: parent class.
+ * @can_probe: returns %TRUE if the files can be probed.
+ * @probe: probes the file.
+ * @open: opens and reads the file.
+ *
+ * File opener base class.
+ **/
+
 static void
 go_file_opener_init (GOFileOpener *fo)
 {
@@ -88,18 +124,15 @@ go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
 
 static void
 go_file_opener_open_real (GOFileOpener const *fo, gchar const *opt_enc,
-			  GOIOContext *io_context,
-			  gpointer FIXME_workbook_view,
-			  GsfInput *input)
+                          GOIOContext *io_context, GoView *view,
+                          GsfInput *input)
 {
 	if (fo->open_func != NULL) {
 		if (fo->encoding_dependent)
 			((GOFileOpenerOpenFuncWithEnc)fo->open_func)
-				(fo, opt_enc, io_context,
-				 FIXME_workbook_view, input);
+				(fo, opt_enc, io_context, view, input);
 		else
-			fo->open_func (fo, io_context,
-				       FIXME_workbook_view, input);
+			fo->open_func (fo, io_context, view, input);
 	} else
 		go_io_error_unknown (io_context);
 }
@@ -123,11 +156,11 @@ GSF_CLASS (GOFileOpener, go_file_opener,
  * @fo: Newly created GOFileOpener object
  * @id: Optional ID of the opener (or NULL)
  * @description: Description of supported file format
- * @suffixes: List of suffixes to associate with the opener
- * @mimes: List of mime types to associate with the opener
+ * @suffixes: (element-type char): List of suffixes to associate with the opener
+ * @mimes: (element-type char): List of mime types to associate with the opener
  * @encoding_dependent: whether the opener depends on an encoding sel.
- * @probe_func: Optional pointer to "probe" function (or NULL)
- * @open_func: Pointer to "open" function
+ * @probe_func: (scope async):  Optional pointer to "probe" function (or NULL)
+ * @open_func: (scope async): Pointer to "open" function
  *
  * Sets up GOFileOpener object, newly created with g_object_new function.
  * This is intended to be used only by GOFileOpener derivates.
@@ -158,15 +191,15 @@ go_file_opener_setup (GOFileOpener *fo, gchar const *id,
  * go_file_opener_new:
  * @id: Optional ID of the opener (or NULL)
  * @description: Description of supported file format
- * @suffixes: List of suffixes to associate with the opener
- * @mimes: List of mime types to associate with the opener
- * @probe_func: Optional pointer to "probe" function (or NULL)
- * @open_func: Pointer to "open" function
+ * @suffixes: (element-type char): List of suffixes to associate with the opener
+ * @mimes: (element-type char): List of mime types to associate with the opener
+ * @probe_func: (scope async): Optional pointer to "probe" function (or NULL)
+ * @open_func: (scope async): Pointer to "open" function
  *
  * Creates new GOFileOpener object. Optional @id will be used
  * after registering it with go_file_opener_register function.
  *
- * Returns: newly created GOFileOpener object.
+ * Returns: (transfer full): newly created GOFileOpener object.
  **/
 GOFileOpener *
 go_file_opener_new (gchar const *id,
@@ -189,15 +222,15 @@ go_file_opener_new (gchar const *id,
  * go_file_opener_new_with_enc:
  * @id: Optional ID of the opener (or NULL)
  * @description: Description of supported file format
- * @suffixes: List of suffixes to associate with the opener
- * @mimes: List of mime types to associate with the opener
- * @probe_func: Optional pointer to "probe" function (or NULL)
- * @open_func: Pointer to "open" function
+ * @suffixes: (element-type char): List of suffixes to associate with the opener
+ * @mimes: (element-type char): List of mime types to associate with the opener
+ * @probe_func: (scope async): Optional pointer to "probe" function (or NULL)
+ * @open_func: (scope async): Pointer to "open" function
  *
  * Creates new GOFileOpener object. Optional @id will be used
  * after registering it with go_file_opener_register function.
  *
- * Returns: newly created #GOFileOpener object.
+ * Returns: (transfer full): newly created #GOFileOpener object.
  **/
 GOFileOpener *
 go_file_opener_new_with_enc (gchar const *id,
@@ -250,12 +283,25 @@ go_file_opener_can_probe (GOFileOpener const *fo, GOFileProbeLevel pl)
 	return GO_FILE_OPENER_METHOD (fo, can_probe) (fo, pl);
 }
 
+/**
+ * go_file_opener_get_suffixes:
+ * @fo: #GOFileOpener
+ *
+ * Returns: (element-type char) (transfer none): the suffixes for the supporte file types.
+ **/
 GSList const *
 go_file_opener_get_suffixes (GOFileOpener const *fo)
 {
 	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), NULL);
 	return fo->suffixes;
 }
+
+/**
+ * go_file_opener_get_mimes:
+ * @fo: #GOFileOpener
+ *
+ * Returns: (element-type char) (transfer none): the supported mime types.
+ **/
 GSList const *
 go_file_opener_get_mimes (GOFileOpener const *fo)
 {
@@ -293,7 +339,7 @@ go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel
  * @fo: GOFileOpener object
  * @opt_enc: Optional encoding
  * @io_context: Context for i/o operation
- * @FIXME_workbook_view: Workbook View
+ * @view: #GoView
  * @input: Gsf input stream
  *
  * Reads content of @file_name file into workbook @wbv is attached to.
@@ -305,19 +351,27 @@ go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel
 void
 go_file_opener_open (GOFileOpener const *fo, gchar const *opt_enc,
 		     GOIOContext *io_context,
-		     gpointer FIXME_workbook_view, GsfInput *input)
+		      GoView *view, GsfInput *input)
 {
 	g_return_if_fail (GO_IS_FILE_OPENER (fo));
 	g_return_if_fail (GSF_IS_INPUT (input));
 
-	GO_FILE_OPENER_METHOD (fo, open) (fo, opt_enc, io_context,
-					  FIXME_workbook_view, input);
+	GO_FILE_OPENER_METHOD (fo, open) (fo, opt_enc, io_context, view, input);
 }
 
 /*
  * GOFileSaver
  */
 
+/**
+ * GOFileSaverClass:
+ * @parent_class: parent class.
+ * @save: saves the file.
+ * @set_export_options: set the options.
+ *
+ * File saver base class.
+ **/
+
 static void
 go_file_saver_init (GOFileSaver *fs)
 {
@@ -447,14 +501,14 @@ go_file_saver_get_property (GObject *object, guint property_id,
 
 static void
 go_file_saver_save_real (GOFileSaver const *fs, GOIOContext *io_context,
-			 gconstpointer FIXME_workbook_view, GsfOutput *output)
+			 GoView const *view, GsfOutput *output)
 {
 	if (fs->save_func == NULL) {
 		go_io_error_unknown (io_context);
 		return;
 	}
 
-	fs->save_func (fs, io_context, FIXME_workbook_view, output);
+	fs->save_func (fs, io_context, view, output);
 }
 
 static void
@@ -564,7 +618,7 @@ GSF_CLASS (GOFileSaver, go_file_saver,
  * @extension: Optional default extension of saved files (or NULL)
  * @description: Description of supported file format
  * @level: File format level
- * @save_func: Pointer to "save" function
+ * @save_func: (scope async): Pointer to "save" function
  *
  * Creates new GOFileSaver object. Optional @id will be used
  * after registering it with go_file_saver_register or
@@ -666,7 +720,7 @@ go_file_saver_set_export_options (GOFileSaver *fs,
  * go_file_saver_save:
  * @fs: GOFileSaver object
  * @io_context: Context for i/o operation
- * @FIXME_workbook_view: Workbook View
+ * @view: #GoView
  * @output: Output stream
  *
  * Saves @wbv and the workbook it is attached to into @output stream.
@@ -677,8 +731,7 @@ go_file_saver_set_export_options (GOFileSaver *fs,
  */
 void
 go_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
-		    gconstpointer FIXME_workbook_view,
-		    GsfOutput *output)
+		    GoView *view, GsfOutput *output)
 {
 	g_return_if_fail (GO_IS_FILE_SAVER (fs));
 	g_return_if_fail (GSF_IS_OUTPUT (output));
@@ -716,8 +769,7 @@ go_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
 		g_free (file_name);
 	}
 
-	GO_FILE_SAVER_METHOD (fs, save) (fs, io_context,
-					 FIXME_workbook_view, output);
+	GO_FILE_SAVER_METHOD (fs, save) (fs, io_context, view, output);
 }
 
 /**
@@ -987,7 +1039,7 @@ go_file_saver_unregister (GOFileSaver *fs)
  * Finds file saver registered as default saver with the highest priority.
  * Reference count for the saver is NOT incremented.
  *
- * Returns: GOFileSaver object or NULL if default saver is not
+ * Returns: (transfer none): GOFileSaver object or NULL if default saver is not
  *               available.
  **/
 GOFileSaver *
@@ -1003,7 +1055,7 @@ go_file_saver_get_default (void)
  * go_file_saver_for_mime_type:
  * @mime_type: A mime type
  *
- * Returns: A #GOFileSaver object associated with @mime_type, or %NULL
+ * Returns: (transfer none): A #GOFileSaver object associated with @mime_type, or %NULL
  **/
 GOFileSaver *
 go_file_saver_for_mime_type (gchar const *mime_type)
@@ -1037,7 +1089,7 @@ go_file_saver_for_mime_type (gchar const *mime_type)
  * Searches for file saver with given @filename, registered using
  * go_file_opener_register
  *
- * Returns: GOFileSaver object or NULL if opener cannot be found.
+ * Returns: (transfer none): GOFileSaver object or NULL if opener cannot be found.
  **/
 GOFileSaver *
 go_file_saver_for_file_name (char const *file_name)
@@ -1062,7 +1114,7 @@ go_file_saver_for_file_name (char const *file_name)
  * Searches for file opener with given @id, registered using
  * go_file_opener_register
  *
- * Returns: #GOFileOpener object or %NULL if opener cannot be found.
+ * Returns: (transfer none): #GOFileOpener object or %NULL if opener cannot be found.
  **/
 GOFileOpener *
 go_file_opener_for_id (gchar const *id)
@@ -1081,7 +1133,7 @@ go_file_opener_for_id (gchar const *id)
  * Searches for file saver with given @id, registered using
  * go_file_saver_register or register_file_opener_as_default.
  *
- * Returns: GOFileSaver object or NULL if saver cannot be found.
+ * Returns: (transfer none): GOFileSaver object or NULL if saver cannot be found.
  **/
 GOFileSaver *
 go_file_saver_for_id (gchar const *id)
@@ -1096,7 +1148,8 @@ go_file_saver_for_id (gchar const *id)
 /**
  * go_get_file_savers:
  *
- * Returns: list of known# GOFileSaver types (do not modify list)
+ * Returns: (element-type GOFileSaver) (transfer none): list of known
+ * #GOFileSaver types (do not modify list)
  */
 GList *
 go_get_file_savers (void)
@@ -1107,7 +1160,8 @@ go_get_file_savers (void)
 /**
  * go_get_file_openers:
  *
- * Returns: list of known #GOFileOpener types (do not modify list)
+ * Returns: (element-type GOFileSaver) (transfer none): list of known
+ * #GOFileOpener types (do not modify list)
  **/
 GList *
 go_get_file_openers (void)
