@@ -58,6 +58,17 @@
 #include <unistd.h>
 #endif
 
+/**
+ * GOPluginModuleDepend:
+ * @key: object being versioned.
+ * @version: version ID (strict equality is required).
+ **/
+/**
+ * GOPluginModuleHeader:
+ * @magic_number: magic GOffice plugins number.
+ * @num_depends: number of #GOPluginModuleDepend fields.
+ **/
+
 #define PLUGIN_INFO_FILE_NAME          "plugin.xml"
 #define PLUGIN_ID_VALID_CHARS          "_ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
 
@@ -347,7 +358,7 @@ go_plugin_read_full_info_if_needed_go_error_info_ (GOPlugin *plugin, GOErrorInfo
 	old_dir_name = plugin->dir_name;
 	go_plugin_read (plugin, old_dir_name, &read_error);
 	if (read_error == NULL && strcmp (plugin->id, old_id) == 0) {
-		/* id and dir_name pointers are guaranteed to be valid during plugin's lifetime */
+		/* ID and dir_name pointers are guaranteed to be valid during plugin's lifetime */
 		g_free (plugin->id);
 		g_free (plugin->dir_name);
 		plugin->id = old_id;
@@ -357,7 +368,7 @@ go_plugin_read_full_info_if_needed_go_error_info_ (GOPlugin *plugin, GOErrorInfo
 		go_plugin_message (1, "Can't read plugin.xml file for %s.\n", old_id);
 		if (read_error == NULL) {
 			read_error = go_error_info_new_printf (
-			             _("File contains plugin info with invalid id (%s), expected %s."),
+			             _("File contains plugin info with invalid ID (%s), expected %s."),
 			             plugin->id, old_id);
 		}
 		*ret_error = go_error_info_new_str_with_details (
@@ -446,7 +457,8 @@ static GSF_CLASS (GOPluginTypeModule, go_plugin_type_module,
  * go_plugin_get_type_module:
  * @plugin: #GOPlugin
  *
- * Returns: the GTypeModule associated with the plugin creating it if necessary.
+ * Returns: (transfer none): the GTypeModule associated with the plugin
+ * creating it if necessary.
  **/
 GTypeModule *
 go_plugin_get_type_module (GOPlugin *plugin)
@@ -547,12 +559,12 @@ go_plugin_is_loaded (GOPlugin *plugin)
 /* - */
 
 /**
- * plugins_register_loader:
- * @loader_id: Loader's id
+ * go_plugins_register_loader:
+ * @id_str: Loader's id
  * @service: Plugin service of type "plugin_loader"
  *
  * Registers new type of plugin loader identified by @loader_id (identifier
- * consists of loader's plugin id and service id concatenated using colon).
+ * consists of loader's plugin ID and service ID concatenated using colon).
  * All requests to create new loader object of this type will be passed to
  * @service.
  *
@@ -568,8 +580,8 @@ go_plugins_register_loader (gchar const *loader_id, GOPluginService *service)
 }
 
 /**
- * plugins_unregister_loader:
- * @loader_id: Loader's id
+ * go_plugins_unregister_loader:
+ * @id_str: Loader's id
  *
  * Unregisters a type of plugin loader identified by @loader_id. After
  * callingthis function Gnumeric will be unable to load plugins supported
@@ -855,7 +867,7 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error
 
 		if (services_error != NULL) {
 			*ret_error = go_error_info_new_printf (
-				_("Errors while reading services for plugin with id=\"%s\"."),
+				_("Errors while reading services for plugin with ID=\"%s\"."),
 				id);
 			go_error_info_add_details (*ret_error, services_error);
 		} else
@@ -867,7 +879,7 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error
 
 			if (id[strspn (id, PLUGIN_ID_VALID_CHARS)] != '\0') {
 				GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
-					_("Plugin id contains invalid characters (%s)."), id));
+					_("Plugin ID contains invalid characters (%s)."), id));
 			}
 			if (name == NULL) {
 				GO_SLIST_PREPEND (error_list, go_error_info_new_str (
@@ -875,7 +887,7 @@ go_plugin_read (GOPlugin *plugin, gchar const *dir_name, GOErrorInfo **ret_error
 			}
 			if (loader_id == NULL) {
 				GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
-					_("No loader defined or loader id invalid for plugin with id=\"%s\"."), id));
+					_("No loader defined or loader ID invalid for plugin with ID=\"%s\"."), id));
 			}
 			g_assert (error_list != NULL);
 			GO_SLIST_REVERSE (error_list);
@@ -977,13 +989,13 @@ go_plugin_activate (GOPlugin *plugin, GOErrorInfo **ret_error)
 				GOErrorInfo *new_error;
 
 				new_error = go_error_info_new_printf (
-					_("Couldn't activate plugin with id=\"%s\"."), dep->plugin_id);
+					_("Couldn't activate plugin with ID=\"%s\"."), dep->plugin_id);
 				go_error_info_add_details (new_error, dep_error);
 				GO_SLIST_PREPEND (error_list, new_error);
 			}
 		} else {
 			GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
-				_("Couldn't find plugin with id=\"%s\"."), dep->plugin_id));
+				_("Couldn't find plugin with ID=\"%s\"."), dep->plugin_id));
 		}
 	);
 	g_assert (activate_stack != NULL && activate_stack->data == plugin);
@@ -1155,13 +1167,13 @@ go_plugin_load_base (GOPlugin *plugin, GOErrorInfo **ret_error)
 				GOErrorInfo *new_error;
 
 				new_error = go_error_info_new_printf (
-					_("Couldn't load plugin with id=\"%s\"."), dep->plugin_id);
+					_("Couldn't load plugin with ID=\"%s\"."), dep->plugin_id);
 				go_error_info_add_details (new_error, dep_error);
 				GO_SLIST_PREPEND (error_list, new_error);
 			}
 		} else {
 			GO_SLIST_PREPEND (error_list, go_error_info_new_printf (
-				_("Couldn't find plugin with id=\"%s\"."), dep->plugin_id));
+				_("Couldn't find plugin with ID=\"%s\"."), dep->plugin_id));
 		}
 	);
 	g_assert (load_stack != NULL && load_stack->data == plugin);
@@ -1265,7 +1277,8 @@ go_plugin_use_unref (GOPlugin *plugin)
  * go_plugin_get_dependencies_ids:
  * @plugin: #GOPlugin
  *
- * Returns: the list of identifiers of plugins that @plugin depends on.
+ * Returns: (element-type char) (transfer full): the list of identifiers of
+ * plugins that @plugin depends on.
  * 	All these plugins will be automatically activated before activating the
  * 	@plugin itself.  The caller must free the returned list together with
  * 	the strings it points to (use g_slist_free_full (list, g_free) to do
@@ -1287,7 +1300,8 @@ go_plugin_get_dependencies_ids (GOPlugin *plugin)
  * go_plugin_get_services:
  * @plugin: #GOPlugin
  *
- * Returns: A list of services.  The list must not be freed or changed.
+ * Returns: (element-type GOPluginService) (transfer none):A list of services.
+ * The list must not be freed or changed.
  **/
 GSList *
 go_plugin_get_services (GOPlugin *plugin)
@@ -1301,7 +1315,7 @@ go_plugin_get_services (GOPlugin *plugin)
  * go_plugin_get_loader:
  * @plugin: #GOPlugin
  *
- * Returns: The loader.
+ * Returns: (transfer none): The loader.
  **/
 GOPluginLoader *
 go_plugin_get_loader (GOPlugin *plugin)
@@ -1455,8 +1469,8 @@ go_plugin_list_read_for_all_dirs (GOErrorInfo **ret_error)
 }
 
 /**
- * plugin_db_activate_plugin_list:
- * @plugins: The list of plugins
+ * go_plugin_db_activate_plugin_list:
+ * @plugins: (element-type GOPlugin): The list of plugins
  * @ret_error: Pointer used to report errors
  *
  * Activates all plugins in the list. If some of the plugins cannot be
@@ -1490,8 +1504,8 @@ go_plugin_db_activate_plugin_list (GSList *plugins, GOErrorInfo **ret_error)
 }
 
 /**
- * plugin_db_deactivate_plugin_list:
- * @plugins: The list of plugins
+ * go_plugin_db_deactivate_plugin_list:
+ * @plugins: (element-type GOPlugin): The list of plugins
  * @ret_error: Pointer used to report errors
  *
  * Deactivates all plugins in the list. If some of the plugins cannot be
@@ -1525,10 +1539,11 @@ go_plugin_db_deactivate_plugin_list (GSList *plugins, GOErrorInfo **ret_error)
 }
 
 /**
- * plugins_get_available_plugins:
+ * go_plugins_get_available_plugins:
  *
- * Returns: the list of available plugins. The returned value must not be freed
- * 	and stays valid until calling plugins_rescan or plugins_shutdown.
+ * Returns: (element-type GOPlugin) (transfer container): the list of available
+ * plugins. The returned value must not be freed and stays valid until calling
+ * plugins_rescan or plugins_shutdown.
  **/
 GSList *
 go_plugins_get_available_plugins (void)
@@ -1537,10 +1552,10 @@ go_plugins_get_available_plugins (void)
 }
 
 /**
- * plugins_get_active_plugins:
+ * go_plugins_get_active_plugins:
  *
- * Returns: the list of active plugins.  The caller needs to free the list, but
- * 	not the content.
+ * Returns: (element-type char) (transfer container): the list of active
+ * plugins names. The caller needs to free the list, but not the content.
  **/
 GSList *
 go_plugins_get_active_plugins (void)
@@ -1557,10 +1572,10 @@ go_plugins_get_active_plugins (void)
 }
 
 /**
- * plugins_get_plugin_by_id:
+ * go_plugins_get_plugin_by_id:
  * @plugin_id: String containing plugin ID
  *
- * Returns: GOPlugin object for plugin with ID equal to @plugin_id or NULL
+ * Returns: (transfer none): GOPlugin object for plugin with ID equal to @plugin_id or NULL
  * 	if there's no plugin available with given id.  Function returns
  * 	"borrowed" reference, use g_object_ref if you want to be sure that
  * 	plugin won't disappear.
@@ -1574,7 +1589,7 @@ go_plugins_get_plugin_by_id (gchar const *plugin_id)
 }
 
 /**
- * plugin_db_mark_plugin_for_deactivation:
+ * go_plugin_db_mark_plugin_for_deactivation:
  * @plugin: #GOPlugin
  * @mark:
  */
@@ -1596,7 +1611,7 @@ go_plugin_db_mark_plugin_for_deactivation (GOPlugin *plugin, gboolean mark)
 }
 
 /**
- * plugin_db_is_plugin_marked_for_deactivation:
+ * go_plugin_db_is_plugin_marked_for_deactivation:
  * @plugin: #GOPlugin
  */
 gboolean
@@ -1615,9 +1630,10 @@ ghf_set_state_old_unused (gpointer key, gpointer value, gpointer unused)
 }
 
 /**
- * plugins_rescan:
+ * go_plugins_rescan:
  * @ret_error: Pointer used to report errors
- * @ret_new_plugins: Optional pointer to return list of new plugins
+ * @ret_new_plugins: (element-type GOPlugin): Optional pointer to return list
+ * of new plugins
  *
  *
  */
@@ -1749,9 +1765,9 @@ go_plugins_set_dirs (GSList *plugin_dirs)
 /**
  * go_plugins_init:
  * @context: #GOCmdContext used to report errors
- * @known_states: A list of known states (defined how ?)
- * @active_plugins: A list of active plugins
- * @plugin_dirs:a list of directories to search for plugins
+ * @known_states: (element-type char): A list of known states (defined how ?)
+ * @active_plugins: (element-type char): A list of active plugins
+ * @plugin_dirs: (element-type char): a list of directories to search for plugins
  * @activate_new_plugins: activate plugins we have no seen before.
  * @default_loader_type: importer to use by default.
  *
@@ -1856,11 +1872,14 @@ ghf_collect_used_plugin_state_strings (gpointer key, gpointer value, gpointer us
 }
 
 /**
- * plugins_shutdown:
+ * go_plugins_shutdown:
  *
  * Shuts down the plugin subsystem. Call this function only once before
  * exiting the application. Some plugins may be left active or in broken
  * state, so calling plugins_init again will NOT work properly.
+ *
+ * Returns: (element-type char) (transfer full): the list of plugins still in
+ * use.
  */
 GSList *
 go_plugins_shutdown (void)
