@@ -28,6 +28,28 @@
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
+/**
+ * GogAxisTickProperties:
+ * @tick_in: whether to have tick inside the plot area.
+ * @tick_out: whether to have tick outside the plot area.
+ * @size_pts: tick size.
+ **/
+
+/**
+ * GogAxisPosition:
+ * @GOG_AXIS_AT_LOW: crosses the other axis at low values.
+ * @GOG_AXIS_CROSS: crosses the other axis at a given value.
+ * @GOG_AXIS_AT_HIGH: crosses the other axis at high values.
+ * @GOG_AXIS_AUTO: crosses at an automatically determined position.
+ **/
+
+/**
+ * GogAxisTickTypes:
+ * @GOG_AXIS_TICK_NONE: no tick, should not occur.
+ * @GOG_AXIS_TICK_MAJOR: major tick.
+ * @GOG_AXIS_TICK_MINOR: minor tick.
+ **/
+
 static GogViewClass *gab_view_parent_klass;
 static GObjectClass *gab_parent_klass;
 
@@ -271,6 +293,12 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 	return crossed_type;
 }
 
+/**
+ * gog_axis_base_get_crossed_axis:
+ * @axis_base: #GogAxisBase
+ *
+ * Returns: (transfer none): returns the crossing axis in a 2D chart if set.
+ **/
 GogAxis *
 gog_axis_base_get_crossed_axis (GogAxisBase *axis_base)
 {
@@ -489,7 +517,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		return;
 	}
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL) {
 		(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 		return;
@@ -701,7 +729,7 @@ gog_axis_base_class_init (GObjectClass *gobject_klass)
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_CROSS_AXIS_ID,
 		g_param_spec_uint ("cross-axis-id",
-			_("Cross axis id"),
+			_("Cross axis ID"),
 			_("Which axis to cross"),
 			0, G_MAXUINT, 0,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
