@@ -44,6 +44,34 @@
  * #GogLabel objects in the role "Label".
  */
 
+/**
+ * GogAxisPolarUnit:
+ * @GOG_AXIS_POLAR_UNIT_DEGREES: units as degrees.
+ * @GOG_AXIS_POLAR_UNIT_RADIANS: units as radians.
+ * @GOG_AXIS_POLAR_UNIT_GRADS: units as grads.
+ * @GOG_AXIS_POLAR_UNIT_MAX: maximum values, should not occur.
+ **/
+
+/**
+ * GogAxisTick:
+ * @position: position on the axis.
+ * @type: #GogAxisTickTypes
+ * @str: label, might be rich text.
+ **/
+
+/**
+ * GogAxisElemType:
+ * @GOG_AXIS_ELEM_MIN: minimum value.
+ * @GOG_AXIS_ELEM_MAX: maximum value.
+ * @GOG_AXIS_ELEM_MAJOR_TICK: distance between two major ticks.
+ * @GOG_AXIS_ELEM_MINOR_TICK: distance between two minor ticks.
+ * @GOG_AXIS_ELEM_CROSS_POINT: position of the other axis crossing.
+ * @GOG_AXIS_ELEM_MAX_ENTRY: maximum value, should not occur.
+ *
+ * The indices of the #GOData associated to the axis.
+ **/
+
+
 static struct {
 	GogAxisPolarUnit unit;
 	const char 	*name;
@@ -154,6 +182,14 @@ gog_axis_get_date_conv (GogAxis const *axis)
 	return axis->date_conv;
 }
 
+/**
+ * gog_axis_get_effective_format:
+ * @axis: #GogAxis
+ *
+ * Returns: (transfer none): the #GOFormat used for the axis labels. Differs
+ * from gog_axis_get_format in that it never returns a general format
+ * (see #go_format_is_general).
+ **/
 GOFormat *
 gog_axis_get_effective_format (GogAxis const *axis)
 {
@@ -217,6 +253,7 @@ struct _GogAxisMap {
 	GogAxisMapDesc	const *desc;
 	gpointer	 data;
 	gboolean	 is_valid;	/* Default to FALSE if desc::init == NULL */
+	unsigned     ref_count;
 };
 
 struct _GogAxisMapDesc {
@@ -1574,7 +1611,7 @@ gog_axis_map_is_valid (GogAxisMap *map)
  * gog_axis_map_to_view in order to translates data coordinates
  * into canvas space.
  *
- * Returns: a newly allocated #GogAxisMap.
+ * Returns: (transfer full): a newly allocated #GogAxisMap.
  **/
 GogAxisMap *
 gog_axis_map_new (GogAxis *axis, double offset, double length)
@@ -1590,6 +1627,7 @@ gog_axis_map_new (GogAxis *axis, double offset, double length)
 	map->axis = axis;
 	map->data = NULL;
 	map->is_valid = FALSE;
+	map->ref_count = 1;
 
 	if (axis->type != GOG_AXIS_CIRCULAR) {
 		offset += axis->span_start * length;
@@ -1715,9 +1753,9 @@ gog_axis_map_get_baseline (GogAxisMap *map)
  * @start: location to store start for this axis
  * @stop: location to store stop for this axis
  *
- * Gets start and stop for the given axis map in data coordinates. If
- * axis is not inverted, start = minimum and stop = maximum.  If axis is invalid,
- * it'll return arbitrary bounds.
+ * Gets start and stop for the whole chart relative to the given axis map
+ * in data coordinates. If axis is not inverted, start = minimum and
+ * stop = maximum.  If axis is invalid, it'll return arbitrary bounds.
  *
  * Any of @start and @stop may be NULL.
  **/
@@ -1752,14 +1790,43 @@ gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 		*stop = x1;
 }
 
+/**
+ * gog_axis_map_get_real_extents:
+ * @map: a #GogAxisMap
+ * @start: location to store start for this axis
+ * @stop: location to store stop for this axis
+ *
+ * Gets start and stop for the given axis map in data coordinates. If
+ * axis is not inverted, start = minimum and stop = maximum.  If axis is invalid,
+ * it'll return arbitrary bounds.
+ *
+ * Any of @start and @stop may be NULL.
+ **/
+
+void
+gog_axis_map_get_real_extents (GogAxisMap *map, double *start, double *stop)
+{
+	double x0, x1;
+	g_return_if_fail (map != NULL);
+
+	if (gog_axis_is_inverted (map->axis))
+		map->desc->map_bounds (map, &x1, &x0);
+	else
+		map->desc->map_bounds (map, &x0, &x1);
+	if (start)
+		*start = x0;
+	if (stop)
+		*stop = x1;
+}
+
 /**
  * gog_axis_map_get_bounds:
  * @map: a #GogAxisMap
  * @minimum: location to store minimum for this axis
  * @maximum: location to store maximum for this axis
  *
- * Gets bounds for the given axis map in data coordinates. If axis is invalid,
- * it'll return arbitrary bounds.
+ * Gets bounds for the whole chart relative to the given axis map in data
+ * coordinates. If axis is invalid, it'll return arbitrary bounds.
  *
  * Any of @minimum and @maximum may be NULL.
  **/
@@ -1794,6 +1861,34 @@ gog_axis_map_get_bounds (GogAxisMap *map, double *minimum, double *maximum)
 		*maximum = (map->axis->inverted)? x0: x1;
 }
 
+/**
+ * gog_axis_map_get_real_bounds:
+ * @map: a #GogAxisMap
+ * @minimum: location to store minimum for this axis
+ * @maximum: location to store maximum for this axis
+ *
+ * Gets bounds for the given axis map in data coordinates. If axis is invalid,
+ * it'll return arbitrary bounds.
+ *
+ * Any of @minimum and @maximum may be NULL.
+ **/
+
+void
+gog_axis_map_get_real_bounds (GogAxisMap *map, double *minimum, double *maximum)
+{
+	double x0, x1;
+	g_return_if_fail (map != NULL);
+
+	if (gog_axis_is_inverted (map->axis))
+		map->desc->map_bounds (map, &x1, &x0);
+	else
+		map->desc->map_bounds (map, &x0, &x1);
+	if (minimum)
+		*minimum = (map->axis->inverted)? x1: x0;
+	if (maximum)
+		*maximum = (map->axis->inverted)? x0: x1;
+}
+
 /**
  * gog_axis_map_is_inverted:
  * @map: a #GogAxisMap
@@ -1834,6 +1929,8 @@ gog_axis_map_free (GogAxisMap *map)
 {
 	g_return_if_fail (map != NULL);
 
+	if (map->ref_count-- > 1)
+		return;
 	if (map->desc->destroy != NULL)
 		map->desc->destroy (map);
 
@@ -1842,6 +1939,25 @@ gog_axis_map_free (GogAxisMap *map)
 	g_free (map);
 }
 
+static GogAxisMap *
+gog_axis_map_ref (GogAxisMap *map)
+{
+	map->ref_count++;
+	return map;
+}
+
+GType
+gog_axis_map_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GogAxisMap",
+			 (GBoxedCopyFunc) gog_axis_map_ref,
+			 (GBoxedFreeFunc) gog_axis_map_free);
+	return t;
+}
+
 static void
 gog_axis_auto_bound (GogAxis *axis)
 {
@@ -2037,7 +2153,8 @@ gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
  * gog_axis_get_format:
  * @axis: #GogAxis
  *
- * Returns: the format assigned to @axis but does not add a reference.
+ * Returns: (transfer none): the format assigned to @axis but does not add
+ * a reference.
  **/
 GOFormat *
 gog_axis_get_format (GogAxis const *axis)
@@ -2563,7 +2680,7 @@ gog_axis_populate_editor (GogObject *gobj,
 	GogDataset *set = GOG_DATASET (gobj);
 	GtkBuilder *gui;
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -3011,7 +3128,7 @@ gog_axis_get_ticks (GogAxis *axis, GogAxisTick **ticks)
  * @axis: a #GogAxis
  * @plot_that_labeled_axis: a #GogPlot
  *
- * return value: the possibly NULL #GOData used as a label for this axis
+ * Returns: (transfer none): the possibly NULL #GOData used as a label for this axis
  * along with the plot that it was associated with
  **/
 GOData *
@@ -3091,6 +3208,13 @@ gog_axis_clear_contributors (GogAxis *axis)
 	g_slist_free (list);
 }
 
+/**
+ * gog_axis_contributors:
+ * @axis: #GogAxis
+ *
+ * Returns: (element-type GogObject) (transfer none): the list of the axis
+ * contributors
+ **/
 GSList const *
 gog_axis_contributors (GogAxis *axis)
 {
@@ -3112,11 +3236,12 @@ gog_axis_bound_changed (GogAxis *axis, GogObject *contrib)
 	gog_object_request_update (GOG_OBJECT (axis));
 }
 
-/* gog_axis_get_grid_line:
+/**
+ * gog_axis_get_grid_line:
  * @axis: #GogAxis
  * @major: whether to retrieve major or minor grid line.
  *
- * Returns: a pointer to GridLine object associated to given axis, NULL
+ * Returns: (transfer none): a pointer to GridLine object associated to given axis, NULL
  * if it doesn't exists.
  **/
 GogGridLine *
@@ -3275,7 +3400,8 @@ gog_axis_view_padding_request (GogView *view,
 	GogViewAllocation tmp = *bbox;
 	GogViewRequisition req, available;
 	GogViewPadding label_padding, child_padding;
-	GogChart *chart = GOG_CHART (gog_object_get_parent (view->model));
+	GogObject *parent = gog_object_get_parent (view->model);
+	gboolean is_3d = GOG_IS_CHART (parent) && gog_chart_is_3d (GOG_CHART (parent));
 	GSList *ptr;
 	double const pad_h = gog_renderer_pt2r_y (view->renderer, PAD_HACK);
 	double const pad_w = gog_renderer_pt2r_x (view->renderer, PAD_HACK);
@@ -3288,7 +3414,7 @@ gog_axis_view_padding_request (GogView *view,
 		child = ptr->data;
 		pos = child->model->position;
 		if (GOG_IS_LABEL (child->model) && !(pos & GOG_POSITION_MANUAL)) {
-			if (gog_chart_is_3d (chart)) {
+			if (is_3d) {
 				gog_axis_view_padding_request_3d (view, child,
 					bbox, &label_padding);
 			} else {
@@ -3319,7 +3445,7 @@ gog_axis_view_padding_request (GogView *view,
 		}
 	}
 
-	if (gog_chart_is_3d (chart)) {
+	if (is_3d) {
 		/* For 3d chart we have to calculate how much more padding
 		 * is needed for the axis itself */
 		tmp.x -= label_padding.wl;
