@@ -50,6 +50,7 @@ typedef struct {
 
 typedef struct _GogAxisMap GogAxisMap;
 
+GType		  gog_axis_map_get_type (void);
 GogAxisMap*   gog_axis_map_new	 	  (GogAxis *axis, double offset, double length);
 double	      gog_axis_map 		  (GogAxisMap *map, double value);
 double	      gog_axis_map_to_view	  (GogAxisMap *map, double value);
@@ -58,7 +59,9 @@ double	      gog_axis_map_from_view	  (GogAxisMap *map, double value);
 gboolean      gog_axis_map_finite	  (GogAxisMap *map, double value);
 double	      gog_axis_map_get_baseline	  (GogAxisMap *map);
 void 	      gog_axis_map_get_extents 	  (GogAxisMap *map, double *start, double *stop);
+void 	      gog_axis_map_get_real_extents (GogAxisMap *map, double *start, double *stop);
 void	      gog_axis_map_get_bounds 	  (GogAxisMap *map, double *minimum, double *maximum);
+void 	      gog_axis_map_get_real_bounds (GogAxisMap *map, double *minimum, double *maximum);
 void 	      gog_axis_map_free		  (GogAxisMap *map);
 gboolean      gog_axis_map_is_valid 	  (GogAxisMap *map);
 gboolean      gog_axis_map_is_inverted 	  (GogAxisMap *map);
