@@ -22,12 +22,23 @@
 #include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
 
+/**
+ * GogChartMapPolarData:
+ * @cx: center horizontal position.
+ * @cy: center vertical position.
+ * @rx: available horizontal space from the center.
+ * @ry: available vertical space from the center.
+ * @th0: start angle.
+ * @th1: end angle.
+ **/
+
 struct _GogChartMap {
 	GogChart 		*chart;
 	GogViewAllocation	 area;
 	gpointer	 	 data;
 	GogAxisMap		*axis_map[3];
 	gboolean		 is_valid;
+	unsigned		ref_count;
 
 	void 	 (*map_2D_to_view) 	(GogChartMap *map, double x, double y, double *u, double *v);
 	void 	 (*map_view_to_2D) 	(GogChartMap *map, double x, double y, double *u, double *v);
@@ -593,6 +604,34 @@ xy_make_close_path (GogChartMap *map, double const *x, double const *y,
 			break;
 		case GOG_SERIES_FILL_TYPE_SELF:
 			break;
+		case GOG_SERIES_FILL_TYPE_X_AXIS_MIN:
+			close_path = go_path_new ();
+			gog_axis_map_get_real_bounds (x_map, &position, NULL);
+			position = gog_axis_map_to_view (x_map, position);
+			go_path_move_to (close_path, gog_axis_map_to_view (y_map, y_start), position);
+			go_path_line_to (close_path, gog_axis_map_to_view (y_map, y_end), position);
+			break;
+		case GOG_SERIES_FILL_TYPE_X_AXIS_MAX:
+			close_path = go_path_new ();
+			gog_axis_map_get_real_bounds (x_map, NULL, &position);
+			position = gog_axis_map_to_view (x_map, position);
+			go_path_move_to (close_path, gog_axis_map_to_view (y_map, y_start), position);
+			go_path_line_to (close_path, gog_axis_map_to_view (y_map, y_end), position);
+			break;
+		case GOG_SERIES_FILL_TYPE_Y_AXIS_MIN:
+			close_path = go_path_new ();
+			gog_axis_map_get_real_bounds (y_map, &position, NULL);
+			position = gog_axis_map_to_view (y_map, position);
+			go_path_move_to (close_path, gog_axis_map_to_view (x_map, x_start), position);
+			go_path_line_to (close_path, gog_axis_map_to_view (x_map, x_end), position);
+			break;
+		case GOG_SERIES_FILL_TYPE_Y_AXIS_MAX:
+			close_path = go_path_new ();
+			gog_axis_map_get_real_bounds (y_map, NULL, &position);
+			position = gog_axis_map_to_view (y_map, position);
+			go_path_move_to (close_path, gog_axis_map_to_view (x_map, x_start), position);
+			go_path_line_to (close_path, gog_axis_map_to_view (x_map, x_end), position);
+			break;
 		default:
 			break;
 	}
@@ -807,7 +846,7 @@ polar_make_close_path (GogChartMap *map, double const *x, double const *y,
  *
  * Convenience function for retrieving data related to polar plot layout.
  *
- * returns: a #GogChartMapPolarData struct.
+ * returns: (transfer none): a #GogChartMapPolarData struct.
  **/
 
 GogChartMapPolarData *
@@ -828,7 +867,7 @@ gog_chart_map_get_polar_parms (GogChartMap *map)
  * Creates a new #GogChartMap, used for conversion from data space
  * to canvas space.
  *
- * returns: a new #GogChartMap object.
+ * returns: (transfer full): a new #GogChartMap object.
  **/
 
 GogChartMap *
@@ -852,6 +891,7 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 	map->data = NULL;
 	map->is_valid = FALSE;
 	map->axis_map[0] = map->axis_map[1] = map->axis_map[2] = NULL;
+	map->ref_count = 1;
 
 	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_X:
@@ -1006,7 +1046,7 @@ gog_chart_map_view_to_2D (GogChartMap *map, double x, double y, double *u, doubl
  *
  * Valid values are in range [0..2].
  *
- * returns: a #GogAxisMap.
+ * returns: (transfer none): a #GogAxisMap.
  **/
 
 GogAxisMap *
@@ -1052,6 +1092,8 @@ gog_chart_map_free (GogChartMap *map)
 
 	g_return_if_fail (map != NULL);
 
+	if (map->ref_count-- > 1)
+		return;
 	for (i = 0; i < 3; i++)
 		if (map->axis_map[i] != NULL)
 			gog_axis_map_free (map->axis_map[i]);
@@ -1061,6 +1103,25 @@ gog_chart_map_free (GogChartMap *map)
 	g_free (map);
 }
 
+static GogChartMap *
+gog_chart_map_ref (GogChartMap *map)
+{
+	map->ref_count++;
+	return map;
+}
+
+GType
+gog_chart_map_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0)
+		t = g_boxed_type_register_static ("GogChartMap",
+			 (GBoxedCopyFunc) gog_chart_map_ref,
+			 (GBoxedFreeFunc) gog_chart_map_free);
+	return t;
+}
+
 /**
  * gog_chart_map_make_path:
  * @map: a #GogChartMap
