@@ -1164,7 +1164,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	GtkBuilder *gui;
 	GOStyle *style;
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-guru-type-selector.ui", GETTEXT_PACKAGE, s->cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-guru-type-selector.ui", GETTEXT_PACKAGE, s->cc);
 
 	typesel = g_new0 (GraphGuruTypeSelector, 1);
 	typesel->state = s;
@@ -1257,7 +1257,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 static gboolean
 graph_guru_init (GraphGuruState *s)
 {
-	s->gui = go_gtk_builder_new_internal ("res:go:graph/gog-guru.ui", GETTEXT_PACKAGE, s->cc);
+	s->gui = go_gtk_builder_load_internal ("res:go:graph/gog-guru.ui", GETTEXT_PACKAGE, s->cc);
         if (s->gui == NULL)
                 return TRUE;
 
@@ -1280,7 +1280,7 @@ graph_guru_init (GraphGuruState *s)
  * up the relationship between goffice and gnumeric to decide which parts of
  * the help live where.
  *
- * Returns: #GtkWidget associated with the gurus help button.
+ * Returns: (transfer none): #GtkWidget associated with the gurus help button.
  **/
 GtkWidget *
 gog_guru_get_help_button (GtkWidget *guru)
@@ -1300,7 +1300,7 @@ gog_guru_get_help_button (GtkWidget *guru)
  * 	: drop the @toplevel window argument and have the callers handle
  * 	  widget_show and set_transient
  *
- * Returns: the dialog, and shows new graph guru.
+ * Returns: (transfer full): the dialog, and shows new graph guru.
  **/
 GtkWidget *
 gog_guru (GogGraph *graph, GogDataAllocator *dalloc,
