@@ -60,11 +60,62 @@
  * GOffice ships a number of common plot implementations by default.
  */
 
+/**
+ * GogPlotClass:
+ * @desc: #GogPlotDesc
+ * @series_type: series type.
+ * @axis_set: set of use axes.
+ * @axis_get_bounds: requests the axis bounds
+ * @supports_vary_style_by_element: %TRUE if each element has its own style.
+ * @enum_in_reverse: %TRUE if the plot prefers to display series in reverse
+ * order for legends (e.g. stacked plots want top element to be the
+ * last series.
+ * @foreach_elem: enumerates the elements visible in the legend.
+ * @update_3d: updates 3D (and contour) plots.
+ * @guru_helper: customizes a new plot in the graph editor dialog.
+ * @get_percent: get the value as a percentage.
+ **/
+
+/**
+ * GogPlotViewClass:
+ * @get_data_at_point: returns the data index at the given position, -1 if none.
+ **/
+
+/**
+ * GogPlotBoundInfo:
+ * @is_discrete: whether the data are discrete.
+ * @center_on_ticks: whether to center data on ticks.
+ * @fmt: #GOFormat to use.
+ * @date_conv: the used #GODateConventions.
+ *
+ * Used by plots to give formating informations to each axis.
+ * GogPlotBoundInfo::val are the values limits, GogPlotBoundInfo::logical are
+ * the actual needed display limits.
+ **/
+
+/**
+ * GogPlotDesc:
+ * @series: series description.
+ **/
+
+/**
+ * GogPlotRenderingOrder:
+ * @GOG_PLOT_RENDERING_LAST: render after axis and grid lines.
+ * @GOG_PLOT_RENDERING_BEFORE_AXIS: render before axis but after grid lines.
+ * @GOG_PLOT_RENDERING_BEFORE_GRID: render before grid lines.
+ **/
+
 enum {
 	PLOT_PROP_0,
 	PLOT_PROP_VARY_STYLE_BY_ELEMENT,
 	PLOT_PROP_AXIS_X,
 	PLOT_PROP_AXIS_Y,
+	PLOT_PROP_AXIS_Z,
+	PLOT_PROP_AXIS_CIRCULAR,
+	PLOT_PROP_AXIS_RADIAL,
+	PLOT_PROP_AXIS_PSEUDO_3D,
+	PLOT_PROP_AXIS_COLOR,
+	PLOT_PROP_AXIS_BUBBLE,
 	PLOT_PROP_GROUP,
 	PLOT_PROP_DEFAULT_INTERPOLATION,
 	PLOT_PROP_GURU_HINTS
@@ -195,7 +246,7 @@ gog_plot_populate_editor (GogObject *obj,
 
 	g_return_if_fail (chart != NULL);
 
-	if (gog_chart_get_axis_set (chart) == GOG_AXIS_SET_XY) {
+	if ((gog_chart_get_axis_set (chart) & GOG_AXIS_SET_FUNDAMENTAL) == GOG_AXIS_SET_XY) {
 		GtkWidget *combo;
 		GtkWidget *table = gtk_table_new (0, 1, FALSE);
 
@@ -277,6 +328,24 @@ gog_plot_set_property (GObject *obj, guint param_id,
 	case PLOT_PROP_AXIS_Y:
 		gog_plot_set_axis_by_id (plot, GOG_AXIS_Y, g_value_get_uint (value));
 		break;
+	case PLOT_PROP_AXIS_Z:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_Z, g_value_get_uint (value));
+		break;
+	case PLOT_PROP_AXIS_CIRCULAR:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_CIRCULAR, g_value_get_uint (value));
+		break;
+	case PLOT_PROP_AXIS_RADIAL:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_RADIAL, g_value_get_uint (value));
+		break;
+	case PLOT_PROP_AXIS_PSEUDO_3D:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_PSEUDO_3D, g_value_get_uint (value));
+		break;
+	case PLOT_PROP_AXIS_COLOR:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_COLOR, g_value_get_uint (value));
+		break;
+	case PLOT_PROP_AXIS_BUBBLE:
+		gog_plot_set_axis_by_id (plot, GOG_AXIS_BUBBLE, g_value_get_uint (value));
+		break;
 	case PLOT_PROP_GROUP: {
 		char const *group = g_value_get_string (value);
 		g_free (plot->plot_group);
@@ -313,6 +382,24 @@ gog_plot_get_property (GObject *obj, guint param_id,
 	case PLOT_PROP_AXIS_Y:
 		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_Y));
 		break;
+	case PLOT_PROP_AXIS_Z:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_Z));
+		break;
+	case PLOT_PROP_AXIS_CIRCULAR:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_CIRCULAR));
+		break;
+	case PLOT_PROP_AXIS_RADIAL:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_RADIAL));
+		break;
+	case PLOT_PROP_AXIS_PSEUDO_3D:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_PSEUDO_3D));
+		break;
+	case PLOT_PROP_AXIS_COLOR:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_COLOR));
+		break;
+	case PLOT_PROP_AXIS_BUBBLE:
+		g_value_set_uint (value, gog_plot_get_axis_id (plot, GOG_AXIS_BUBBLE));
+		break;
 	case PLOT_PROP_GROUP:
 		g_value_set_string (value, plot->plot_group);
 		break;
@@ -369,7 +456,7 @@ gog_plot_class_init (GogObjectClass *gog_klass)
 	g_object_class_install_property (gobject_klass, PLOT_PROP_VARY_STYLE_BY_ELEMENT,
 		g_param_spec_boolean ("vary-style-by-element",
 			_("Vary style by element"),
-			_("Use a different style for each segments"),
+			_("Use a different style for each segment"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_X,
@@ -384,6 +471,42 @@ gog_plot_class_init (GogObjectClass *gog_klass)
 			_("Reference to Y axis"),
 			0, G_MAXINT, 0,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_Z,
+		g_param_spec_uint ("z-axis",
+			_("Z axis"),
+			_("Reference to Z axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_CIRCULAR,
+		g_param_spec_uint ("circ-axis",
+			_("Circular axis"),
+			_("Reference to circular axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_RADIAL,
+		g_param_spec_uint ("radial-axis",
+			_("Radial axis"),
+			_("Reference to radial axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_PSEUDO_3D,
+		g_param_spec_uint ("pseudo-3d-axis",
+			_("Pseudo-3D axis"),
+			_("Reference to pseudo-3D axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_COLOR,
+		g_param_spec_uint ("color-axis",
+			_("Color axis"),
+			_("Reference to color axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, PLOT_PROP_AXIS_BUBBLE,
+		g_param_spec_uint ("bubble-axis",
+			_("Bubble axis"),
+			_("Reference to bubble axis"),
+			0, G_MAXINT, 0,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_GROUP,
 		g_param_spec_string ("plot-group",
 			_("Plot group"),
@@ -448,7 +571,7 @@ gog_plot_new_by_type (GogPlotType const *type)
  * gog_plot_new_series:
  * @plot: #GogPlot
  *
- * Returns: a new GogSeries of a type consistent with @plot.
+ * Returns: (transfer none): a new GogSeries of a type consistent with @plot.
  **/
 GogSeries *
 gog_plot_new_series (GogPlot *plot)
@@ -460,6 +583,13 @@ gog_plot_new_series (GogPlot *plot)
 	res = gog_object_add_by_name (GOG_OBJECT (plot), "Series", NULL);
 	return res ? GOG_SERIES (res) : NULL;
 }
+
+/**
+ * gog_plot_description: (skip)
+ * @plot: #GogPlot
+ *
+ * Returns: (transfer none): the #GogPlotDesc for @plot.
+ **/
 GogPlotDesc const *
 gog_plot_description (GogPlot const *plot)
 {
@@ -570,6 +700,15 @@ gog_plot_enum_in_reverse (GogPlot const *plot)
 	return klass != NULL && klass->enum_in_reverse && (klass->enum_in_reverse) (plot);
 }
 
+/**
+ * gog_plot_foreach_elem:
+ * @plot: #GogPlot
+ * @only_visible: whether to restrict to visible elements.
+ * @handler: (scope call): #GogEnumFunc
+ * @data: user data for @func
+ *
+ * Executes @funcfor each plot element. Used to build a legend.
+ **/
 void
 gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 		       GogEnumFunc func, gpointer data)
@@ -670,7 +809,7 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
  * gog_plot_get_series:
  * @plot: #GogPlot
  *
- * Returns: (transfer none): A list of the series in @plot.  Do not modify or free the list.
+ * Returns: (transfer none) (element-type GogSeries) : A list of the series in @plot.  Do not modify or free the list.
  **/
 GSList const *
 gog_plot_get_series (GogPlot const *plot)
@@ -693,7 +832,7 @@ gog_plot_get_series (GogPlot const *plot)
  *
  * Caller is responsible for unrefing ::fmt.
  *
- * Returns: The data providing the bound (does not add a ref)
+ * Returns: (transfer none): The data providing the bound (does not add a ref)
  **/
 GOData *
 gog_plot_get_axis_bounds (GogPlot *plot, GogAxisType axis,
@@ -862,6 +1001,13 @@ gog_plot_get_axis_id (GogPlot const *plot, GogAxisType type)
 	return axis != NULL ? gog_object_get_id (GOG_OBJECT (axis)) : 0;
 }
 
+/**
+ * gog_plot_get_axis:
+ * @plot: #GogPlot
+ * type: #GogAxisType
+ *
+ * Returns: (transfer none): the axis if any.
+ */
 GogAxis	*
 gog_plot_get_axis (GogPlot const *plot, GogAxisType type)
 {
