@@ -28,6 +28,27 @@
 static GObjectClass *data_label_parent_klass;
 static GObjectClass *series_labels_parent_klass;
 
+/**
+ * GogSeriesLabelElt:
+ * @str: the string to display.
+ * @legend_pos: the label position.
+ * @point: #GogObject
+}
+**/
+
+/**
+ * GogSeriesLabelsPos:
+ * @GOG_SERIES_LABELS_DEFAULT_POS: default position.
+ * @GOG_SERIES_LABELS_CENTERED: centered.
+ * @GOG_SERIES_LABELS_TOP: at top.
+ * @GOG_SERIES_LABELS_BOTTOM: at bottom.
+ * @GOG_SERIES_LABELS_LEFT: at left.
+ * @GOG_SERIES_LABELS_RIGHT: at right.
+ * @GOG_SERIES_LABELS_OUTSIDE: outside the element.
+ * @GOG_SERIES_LABELS_INSIDE: inside the element.
+ * @GOG_SERIES_LABELS_NEAR_ORIGIN: near origin.
+ **/
+
 struct {
 	char const *label;
 	GogSeriesLabelsPos pos;
@@ -354,7 +375,7 @@ gog_series_labels_populate_editor (GogObject *gobj,
 	char const *custom_lbl;
 	gboolean supports_percent;
 
-	gui = go_gtk_builder_new_internal ("res:go:graph/gog-series-labels-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:graph/gog-series-labels-prefs.ui", GETTEXT_PACKAGE, cc);
 	labels_prefs = go_gtk_builder_get_widget (gui, "series-labels-prefs");
 	state->labels = gobj;
 
@@ -1545,3 +1566,39 @@ GogSeriesLabelElt const *gog_series_labels_vector_get_element (GogSeriesLabels c
 	}
 	return NULL;
 }
+
+/************************************************************
+ * The following functions are just there for introspection *
+ ************************************************************/
+
+static GogSeriesLabelElt *
+gog_series_label_elt_copy (GogSeriesLabelElt *elt)
+{
+	GogSeriesLabelElt *res = g_new (GogSeriesLabelElt, 1);
+	res->str = go_string_ref (elt->str);
+	res->legend_pos = elt->legend_pos;
+	res->point = (GogObject *) g_object_ref (elt->point);
+	return res;
+}
+
+static void
+gog_series_label_elt_free (GogSeriesLabelElt *elt)
+{
+	go_string_unref (elt->str);
+	g_object_unref (elt->point);
+	g_free (elt);
+}
+
+GType
+gog_series_label_elt_get_type (void)
+{
+    static GType type = 0;
+
+    if (type == 0)
+		type = g_boxed_type_register_static
+			("GogSeriesLabelElt",
+			 (GBoxedCopyFunc) gog_series_label_elt_copy,
+			 (GBoxedFreeFunc) gog_series_label_elt_free);
+
+    return type;
+}
