@@ -34,6 +34,67 @@
  * A #GogSeries represents a data series that can be added to a #GogPlot.
  */
 
+/**
+ * GogSeriesFillType:
+ * @GOG_SERIES_FILL_TYPE_Y_ORIGIN: from origin ox the X-axis.
+ * @GOG_SERIES_FILL_TYPE_X_ORIGIN: from the origin of the Y-axis
+ * @GOG_SERIES_FILL_TYPE_BOTTOM: from the chart bottom.
+ * @GOG_SERIES_FILL_TYPE_LEFT: from the chart left side.
+ * @GOG_SERIES_FILL_TYPE_TOP: from the chart top.
+ * @GOG_SERIES_FILL_TYPE_RIGHT:, from the chart right side.
+ * @GOG_SERIES_FILL_TYPE_ORIGIN: from the origin (for radar and polar plots).
+ * @GOG_SERIES_FILL_TYPE_CENTER: from the center (for radar and polar plots).
+ * @GOG_SERIES_FILL_TYPE_EDGE: from the edge (for radar and polar plots).
+ * @GOG_SERIES_FILL_TYPE_SELF: close the series curve and fills it.
+ * @GOG_SERIES_FILL_TYPE_NEXT: from next series.
+ * @GOG_SERIES_FILL_TYPE_X_AXIS_MIN: from X-axis minimum.
+ * @GOG_SERIES_FILL_TYPE_X_AXIS_MAX: from X-axis maximum.
+ * @GOG_SERIES_FILL_TYPE_Y_AXIS_MIN: from Y-axis minimum.
+ * @GOG_SERIES_FILL_TYPE_Y_AXIS_MAX: from Y-axis maximum.
+ * @GOG_SERIES_FILL_TYPE_INVALID: invalid, should not happen.
+ **/
+
+/**
+ * GogSeriesClass:
+ * @has_interpolation: supports interpolation.
+ * @has_fill_type: %TRUE if filling is supported.
+ * @valid_fill_type_list: list of supported #GogSeriesFillType values.
+ * @series_element_type: #GType for the series element if supported.
+ * @dim_changed: called when data changed for the series.
+ * @get_xy_data: get X and Y data.
+ * @get_interpolation_params: get interpolation parameters if any, only applies
+ * to constrained cubic spline interpolation.
+ **/
+
+/**
+ * GogSeriesElementClass:
+ * @gse_populate_editor: populates editor.
+ **/
+
+/**
+ * GogSeriesPriority:
+ * @GOG_SERIES_REQUIRED: it must be there.
+ * @GOG_SERIES_SUGGESTED: allocator will fill it in, but use need not.
+ * @GOG_SERIES_OPTIONAL: optional data.
+ * @GOG_SERIES_ERRORS: optional data for error bars.
+ *
+ * Applies to data declarations in #GogSeriesDimDesc.
+ **/
+
+/**
+ * GogSeriesDesc:
+ * @dim: dimensions descriptions.
+ **/
+
+/**
+ * GogSeriesDimDesc:
+ * @name: name.
+ * @priority: priority.
+ * @is_shared: whether the dimension is shared among the series.
+ * @val_type: data type.
+ * @ms_type: data type for foreign formats.
+ **/
+
 /* Keep in sync with GogSeriesFillType enum */
 static struct {
 	GogSeriesFillType  type;
@@ -51,6 +112,10 @@ static struct {
 	{GOG_SERIES_FILL_TYPE_EDGE,	"edge",		N_("Edge")},
 	{GOG_SERIES_FILL_TYPE_SELF,	"self",		N_("Self")},
 	{GOG_SERIES_FILL_TYPE_NEXT,	"next",		N_("Next series")},
+	{GOG_SERIES_FILL_TYPE_X_AXIS_MIN,	"x-axis-min",	N_("X axis minimum")},
+	{GOG_SERIES_FILL_TYPE_X_AXIS_MAX,	"x-axis-max",	N_("X axis maximum")},
+	{GOG_SERIES_FILL_TYPE_Y_AXIS_MIN,	"y-axis-min",	N_("Y axis minimum")},
+	{GOG_SERIES_FILL_TYPE_Y_AXIS_MAX,	"y-axis-max",	N_("Y axis maximum")},
 	{GOG_SERIES_FILL_TYPE_INVALID,	"invalid",	""}
 };
 
@@ -558,7 +623,7 @@ gog_series_populate_editor (GogObject *gobj,
 		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_gtk_builder_new_internal ("res:go:graph/gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_load_internal ("res:go:graph/gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			int i;
 			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
@@ -613,7 +678,7 @@ gog_series_populate_editor (GogObject *gobj,
 		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_gtk_builder_new_internal ("res:go:graph/gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_load_internal ("res:go:graph/gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			widget = go_gtk_builder_get_widget (gui, "fill_type_combo");
 				gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
@@ -881,7 +946,7 @@ GSF_CLASS_FULL (GogSeries, gog_series,
  * gog_series_get_plot:
  * @series: #GogSeries
  *
- * Returns: the possibly NULL plot that contains this series.
+ * Returns: (transfer none): the possibly NULL plot that contains this series.
  **/
 GogPlot *
 gog_series_get_plot (GogSeries const *series)
@@ -984,7 +1049,7 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
  * Gets the _source_ of the name associated with the series.
  * NOTE : this is _NOT_ the actual name.
  *
- * return value: a #GODataScalar, without added reference.
+ * return value: (transfer none): a #GODataScalar, without added reference.
  **/
 GOData *
 gog_series_get_name (GogSeries const *series)
@@ -1063,6 +1128,14 @@ gog_series_num_elements (GogSeries const *series)
 	return series->num_elements;
 }
 
+/**
+ * gog_series_get_overrides:
+ * @series: #GogSeries
+ *
+ * Overrides are data owning their own style, overriding the series style.
+ * Returns: (element-type GogSeriesElement) (transfer none): the series
+ * overrides.
+ **/
 GList const *
 gog_series_get_overrides (GogSeries const *series)
 {
@@ -1105,6 +1178,14 @@ gog_series_get_valid_element_index (GogSeries const *series, int old_index, int
 	return old_index;
 }
 
+/**
+ * gog_series_get_element:
+ * @series: #GogSeries
+ * @index: the element index
+ *
+ * Returns: (transfer none): the #GogSeriesElement corresponding to @index if
+ * any
+ **/
 GogSeriesElement *
 gog_series_get_element (GogSeries const *series, int index)
 {
@@ -1265,6 +1346,14 @@ gog_series_get_fill_type_from_combo (GogSeries const *series, GtkComboBox *combo
 }
 #endif
 
+/**
+ * gog_series_get_interpolation_params:
+ * @series: #GogSeries
+ *
+ * Only constrained cubic spline interpolation use parameters (for the
+ * slopes at each end).
+ * Returns: (transfer none): the interpolation parameters.
+ **/
 GogDataset *
 gog_series_get_interpolation_params (GogSeries const *series)
 {
