@@ -25,8 +25,80 @@
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
+/**
+ * GogViewClass:
+ * @base: base class.
+ * @state_init: state intialization.
+ * @padding_request: padding request.
+ * @size_request: size request.
+ * @size_allocate: size allocate.
+ * @render: render to cairo.
+ * @build_toolkit: builds the associated toolkit.
+ * @get_tip_at_point: gets tip at pointer position.
+ * @natural_size: gets natural size.
+ *
+ * the GogViewClass::clip firled should be set to %TRUE to clip drawings to
+ * the vew allocation.
+ **/
+
+/**
+ * GogViewAllocation:
+ * @w: width.
+ * @h: height.
+ * @x: horizontal position.
+ * @y: vertical position.
+ **/
+
+/**
+ * GogViewPadding:
+ * @wr: right padding.
+ * @hb: bottom padding.
+ * @wl: left pdding.
+ * @ht: top padding.
+ **/
+
+/**
+ * GogViewRequisition:
+ * @w: width.
+ * @h: height.
+ **/
+
+static GogViewAllocation *
+gog_view_allocation_copy (GogViewAllocation *alloc)
+{
+	GogViewAllocation *res = g_new (GogViewAllocation, 1);
+	memcpy (res, alloc, sizeof (GogViewAllocation));
+	return res;
+}
+
+GType
+gog_view_allocation_get_type (void)
+{
+    static GType type = 0;
+
+    if (type == 0)
+	type = g_boxed_type_register_static
+	    ("GogViewAllocation",
+	     (GBoxedCopyFunc) gog_view_allocation_copy,
+	     (GBoxedFreeFunc) g_free);
+
+    return type;
+}
+
 /*****************************************************************************/
 
+/**
+ * GogTool:
+ * @name: tool name.
+ * @cursor_type: pointer cursor type for the tool.
+ * @point: points an object.
+ * @render: displays the tool.
+ * @init: initalizes an action.
+ * @move: callback for pointer move.
+ * @double_click: callback on double click.
+ * @destroy: destroys the action.
+ **/
+
 #ifdef GOFFICE_WITH_GTK
 static gboolean
 gog_tool_select_object_point (GogView *view, double x, double y, GogObject **gobj)
@@ -184,6 +256,35 @@ static GogTool gog_tool_resize_object = {
 
 /*****************************************************************************/
 
+/**
+ * GogToolAction:
+ * @start_x: initial pointer horizontal position.
+ * @start_y: initial pointer vertical position.
+ * @view: #GogView
+ * @tool: #GogTool
+ * @data: user data.
+ **/
+
+static GogToolAction *
+gog_tool_action_ref (GogToolAction *action)
+{
+	action->ref_count++;
+	return action;
+}
+
+GType
+gog_tool_action_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GogToolAction",
+			 (GBoxedCopyFunc)gog_tool_action_ref,
+			 (GBoxedFreeFunc)gog_tool_action_free);
+	}
+	return t;
+}
+
 GogToolAction *
 gog_tool_action_new (GogView *view, GogTool *tool, double x, double y)
 {
@@ -200,6 +301,7 @@ gog_tool_action_new (GogView *view, GogTool *tool, double x, double y)
 	action->data = NULL;
 	action->start_x = x;
 	action->start_y = y;
+	action->ref_count = 1;
 
 	if (tool->init != NULL)
 		(tool->init) (action);
@@ -230,6 +332,9 @@ gog_tool_action_free (GogToolAction *action)
 {
 	g_return_if_fail (action != NULL);
 
+	if (action->ref_count-- > 1)
+		return;
+
 	if (action->tool->destroy != NULL)
 		(action->tool->destroy) (action);
 
@@ -604,6 +709,12 @@ GSF_CLASS_ABSTRACT (GogView, gog_view,
 		    gog_view_class_init, gog_view_init,
 		    G_TYPE_OBJECT)
 
+/**
+ * gog_view_get_model:
+ * @view: #GogView
+ *
+ * Returns: (transfer none): the #GogObject owning the view.
+ **/
 GogObject *
 gog_view_get_model (GogView const *view)
 {
@@ -844,7 +955,7 @@ gog_view_size_child_request (GogView *view,
  *
  * Find the GogView contained in @container that corresponds to @model.
  *
- * Returns: NULL on error or if @target_model has no view.
+ * Returns: (transfer none): NULL on error or if @target_model has no view.
  **/
 GogView *
 gog_view_find_child_view  (GogView const *container, GogObject const *target_model)
@@ -909,7 +1020,7 @@ gog_view_render_toolkit (GogView *view)
  * gog_view_get_toolkit:
  * @view: #GogView
  *
- * Returns: toolkit associated with given view.
+ * Returns: (element-type GogTool) (transfer none): toolkit associated with given view.
  **/
 GSList const *
 gog_view_get_toolkit (GogView *view)
@@ -932,7 +1043,7 @@ gog_view_get_toolkit (GogView *view)
  * @y: in coords
  * @gobj: pointed object or NULL
  *
- * Returns: tool under cursor for a given view, or %NULL
+ * Returns: (transfer none): tool under cursor for a given view, or %NULL
  **/
 GogTool *
 gog_view_get_tool_at_point (GogView *view, double x, double y, GogObject **gobj)
@@ -968,7 +1079,7 @@ gog_view_get_tool_at_point (GogView *view, double x, double y, GogObject **gobj)
  * is stored in @obj. This object may or may not be @view->model of pointed view.
  * This function also stores tool under cursor, for the pointed view.
  *
- * return value: the #GogView at x,y position
+ * Returns: (transfer none): the #GogView at x,y position
  **/
 GogView *
 gog_view_get_view_at_point (GogView *view, double x, double y, GogObject **obj, GogTool **tool)
