@@ -32,6 +32,59 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+/**
+ * GORegressionResult:
+ * @GO_REG_ok: success.
+ * @GO_REG_invalid_dimensions: invalid dimensions.
+ * @GO_REG_invalid_data: invalid data:
+ * @GO_REG_not_enough_data: not enough data.
+ * @GO_REG_near_singular_good: probably good result.
+ * @GO_REG_near_singular_bad: probably bad result.
+ * @GO_REG_singular: singularity found.
+ **/
+
+/**
+ * go_regression_stat_t:
+ * @se: SE for each parameter estimator.
+ * @t: t values for each parameter estimator.
+ * @sqr_r: squared R.
+ * @adj_sqr_r:
+ * @se_y: the Standard Error of Y.
+ * @F:
+ * @df_reg:
+ * @df_resid:
+ * @df_total:
+ * @ss_reg:
+ * @ss_resid:
+ * @ss_total:
+ * @ms_reg:
+ * @ms_resid:
+ * @ybar:
+ * @xbar:
+ * @var: the variance of the entire regression: sum(errors^2)/(n-xdim).
+ **/
+
+/**
+ * go_regression_stat_tl:
+ * @se: SE for each parameter estimator.
+ * @t: t values for each parameter estimator.
+ * @sqr_r: squared R.
+ * @adj_sqr_r:
+ * @se_y: the Standard Error of Y.
+ * @F:
+ * @df_reg:
+ * @df_resid:
+ * @df_total:
+ * @ss_reg:
+ * @ss_resid:
+ * @ss_total:
+ * @ms_reg:
+ * @ms_resid:
+ * @ybar:
+ * @xbar:
+ * @var: the variance of the entire regression: sum(errors^2)/(n-xdim).
+ **/
+
 /* ------------------------------------------------------------------------- */
 /* Self-inclusion magic.  */
 
@@ -79,6 +132,37 @@ general_linear_regressionl (long double *const *const xss, int xdim,
 
 #endif
 
+/* Boxed types code */
+
+static SUFFIX(go_regression_stat_t) *
+SUFFIX(go_regression_stat_ref) (SUFFIX(go_regression_stat_t)* state)
+{
+	state->ref_count++;
+	return state;
+}
+
+GType
+#ifdef DEFINE_COMMON
+go_regression_stat_get_type (void)
+#else
+go_regression_statl_get_type (void)
+#endif
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static (
+#ifdef DEFINE_COMMON
+		     "go_regression_stat_t",
+#else
+		     "go_regression_stat_tl",
+#endif
+			 (GBoxedCopyFunc)SUFFIX(go_regression_stat_ref),
+			 (GBoxedFreeFunc)SUFFIX(go_regression_stat_destroy));
+	}
+	return t;
+}
+
 /* ------------------------------------------------------------------------- */
 
 #ifdef DEFINE_COMMON
@@ -145,6 +229,19 @@ general_linear_regressionl (long double *const *const xss, int xdim,
 	}							\
   } while (0)
 
+#define PRINT_QMATRIX(var,dim1,dim2)				\
+  do {								\
+	int _i, _j, _d1, _d2;					\
+	_d1 = (dim1);						\
+	_d2 = (dim2);						\
+	for (_j = 0; _j < _d2; _j++) {				\
+	  for (_i = 0; _i < _d1; _i++) {			\
+		  g_printerr (" %12.8" FORMAT_g, SUFFIX(go_quad_value) (&(var)[_i][_j])); \
+	  }							\
+	  g_printerr ("\n");					\
+	}							\
+  } while (0)
+
 #endif
 
 /*
@@ -585,6 +682,7 @@ SUFFIX(go_matrix_invert) (MATRIX A, int n)
 	QMATRIX R;
 	GORegressionResult err;
 	gboolean has_result;
+	void *state = SUFFIX(go_quad_start) ();
 
 	ALLOC_MATRIX2 (Q, n, n, QUAD);
 	ALLOC_MATRIX2 (R, n, n, QUAD);
@@ -594,25 +692,29 @@ SUFFIX(go_matrix_invert) (MATRIX A, int n)
 
 	if (has_result) {
 		int i, j, k;
+		QUAD *x = g_new (QUAD, n);
+
 		for (k = 0; k < n; k++) {
 			/* Solve R x = Q^T e_k */
 			for (i = n - 1; i >= 0; i--) {
 				QUAD d = Q[i][k];
 				for (j = i + 1; j < n; j++) {
 					QUAD p;
-					SUFFIX(go_quad_init) (&p, A[k][j]);
-					SUFFIX(go_quad_mul) (&p, &R[j][i], &p);
+					SUFFIX(go_quad_mul) (&p, &R[j][i], &x[j]);
 					SUFFIX(go_quad_sub) (&d, &d, &p);
 				}
-				SUFFIX(go_quad_div) (&d, &d, &R[i][i]);
-				A[k][i] = SUFFIX(go_quad_value) (&d);
+				SUFFIX(go_quad_div) (&x[i], &d, &R[i][i]);
+				A[k][i] = SUFFIX(go_quad_value) (&x[i]);
 			}
 		}
+		g_free (x);
 	}
 
 	FREE_MATRIX (Q, n, n);
 	FREE_MATRIX (R, n, n);
 
+	SUFFIX(go_quad_end) (state);
+
 	return has_result;
 }
 
@@ -1458,6 +1560,7 @@ SUFFIX(go_regression_stat_new) (void)
 	stat_->se = NULL;
 	stat_->t = NULL;
 	stat_->xbar = NULL;
+	stat_->ref_count = 1;
 
 	return stat_;
 }
@@ -1467,7 +1570,7 @@ SUFFIX(go_regression_stat_new) (void)
 void
 SUFFIX(go_regression_stat_destroy) (SUFFIX(go_regression_stat_t) *stat_)
 {
-	if (stat_) {
+	if (stat_ && stat_->ref_count-- > 1) {
 		g_free(stat_->se);
 		g_free(stat_->t);
 		g_free(stat_->xbar);
@@ -1745,31 +1848,50 @@ SUFFIX(parameter_errors) (SUFFIX(GORegressionFunction) f,
 	return result;
 }
 
-
-/*
+/**
+ * go_non_linear_regression:
+ * @f: (scope call): the model function
+ * @xvals: independent values.
+ * @par: model parameters.
+ * @yvals: dependent values.
+ * @sigmas: stahdard deviations for the dependent values.
+ * @x_dim: Number of data points.
+ * @p_dim: Number of parameters.
+ * @chi: Chi Squared of the final result.  This value is not very
+ * meaningful without the sigmas.
+ * @errors: MUST ALREADY BE ALLOCATED.  These are the approximated standard
+ * deviation for each parameter.
+ *
  * SYNOPSIS:
  *   result = non_linear_regression (f, xvals, par, yvals, sigmas,
  *                                   x_dim, p_dim, &chi, errors)
- *
- * Returns the results of the non-linear regression from the given initial
+ * Non linear regression.
+ * Returns: the results of the non-linear regression from the given initial
  * values.
- * The resulting parameters are placed back into 'par'.
+ * The resulting parameters are placed back into @par.
+ **/
+/**
+ * go_non_linear_regressionl:
+ * @f: (scope call): the model function
+ * @xvals: independent values.
+ * @par: model parameters.
+ * @yvals: dependent values.
+ * @sigmas: stahdard deviations for the dependent values.
+ * @x_dim: Number of data points.
+ * @p_dim: Number of parameters.
+ * @chi: Chi Squared of the final result.  This value is not very
+ * meaningful without the sigmas.
+ * @errors: MUST ALREADY BE ALLOCATED.  These are the approximated standard
+ * deviation for each parameter.
  *
- * PARAMETERS:
- *
- * sigmas  -> Measurement errors in the dataset (along the y-axis).
- *            NULL means "no errors available", so they are all set to 1.
- *
- * x_dim   -> Number of data points.
- *
- * p_dim   -> Number of parameters.
- *
- * errors  -> MUST ALREADY BE ALLOCATED.  These are the approximated standard
- *            deviation for each parameter.
- *
- * chi     -> Chi Squared of the final result.  This value is not very
- *            meaningful without the sigmas.
- */
+ * SYNOPSIS:
+ *   result = non_linear_regression (f, xvals, par, yvals, sigmas,
+ *                                   x_dim, p_dim, &chi, errors)
+ * Non linear regression.
+ * Returns: the results of the non-linear regression from the given initial
+ * values.
+ * The resulting parameters are placed back into @par.
+ **/
 GORegressionResult
 SUFFIX(go_non_linear_regression) (SUFFIX(GORegressionFunction) f,
 				  MATRIX xvals, /* The entire data set. */
