@@ -26,7 +26,7 @@
 #include <glib/gi18n-lib.h>
 
 /**
- * GOLineDashType
+ * GOLineDashType:
  * @GO_LINE_NONE: No line displayed.
  * @GO_LINE_SOLID: Solid line.
  * @GO_LINE_S_DOT:
@@ -43,7 +43,7 @@
  **/
 
 /**
- * GOLineInterpolation
+ * GOLineInterpolation:
  * @GO_LINE_INTERPOLATION_LINEAR: Linear interpolation.
  * @GO_LINE_INTERPOLATION_SPLINE: Bezier cubic spline interpolation.
  * @GO_LINE_INTERPOLATION_CLOSED_SPLINE: Closed Bezier cubic spline interpolation.
@@ -59,6 +59,48 @@
  * @GO_LINE_INTERPOLATION_MAX: First invalid value.
  **/
 
+/**
+ * GOLineDashSequence:
+ * @offset: offset from start.
+ * @n_dash: number of values in dash fields
+ * @dash: lengths of the dashes segments. See cairo_set_dash() for details.
+ **/
+
+/**
+ * GOArrowType:
+ * @GO_ARROW_NONE: no arrow head.
+ * @GO_ARROW_KITE: kite head.
+ * @GO_ARROW_OVAL: oval head.
+ **/
+
+/**
+ * GOArrow:
+ * @typ: #GOArrowType.
+ * @a: first arrow head size parameter.
+ * @b: second arrow head size parameter.
+ * @c: third arrow head size parameter.
+ **/
+
+static GOLineDashSequence *
+go_line_dash_sequence_ref (GOLineDashSequence * sequence)
+{
+	sequence->ref_count++;
+	return sequence;
+}
+
+GType
+go_line_dash_sequence_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GOLineDashSequence",
+			 (GBoxedCopyFunc)go_line_dash_sequence_ref,
+			 (GBoxedFreeFunc)go_line_dash_sequence_free);
+	}
+	return t;
+}
+
 typedef struct {
 	int 		 n_dash;
 	double		 length;
@@ -254,6 +296,7 @@ go_line_dash_get_sequence (GOLineDashType type, double scale)
 		sequence->dash = g_new (double, sequence->n_dash);
 		for (i = 0; i < sequence->n_dash; i++)
 			sequence->dash[i] = scale * dash_desc->dash[i];
+		sequence->ref_count = 1;
 	}
 
 	return sequence;
@@ -268,8 +311,9 @@ go_line_dash_get_sequence (GOLineDashType type, double scale)
 void
 go_line_dash_sequence_free (GOLineDashSequence *sequence)
 {
-	if (sequence != NULL)
-		g_free (sequence->dash);
+	if (sequence == NULL || sequence->ref_count-- > 1)
+		return;
+	g_free (sequence->dash);
 	g_free (sequence);
 }
 
