@@ -32,6 +32,65 @@
 #include <string.h>
 #include <math.h>
 
+/**
+ * GOImageType:
+ * @GO_IMAGE_STRETCHED: stretch the image so that it fills the whole area.
+ * @GO_IMAGE_WALLPAPER: repeat the image starting from top left.
+ * @GO_IMAGE_CENTERED: use only one image at its natural size, centered in the area.
+ * @GO_IMAGE_CENTERED_WALLPAPER:  repeat the image starting from one at center.
+ **/
+
+/**
+ * GOStyleFill:
+ * @GO_STYLE_FILL_NONE: no filling.
+ * @GO_STYLE_FILL_PATTERN: fill with pattern.
+ * @GO_STYLE_FILL_GRADIENT: fill with a gradient.
+ * @GO_STYLE_FILL_IMAGE: fill with an image.
+ **/
+
+/**
+ * GOStyleFlag:
+ * @GO_STYLE_OUTLINE: outline.
+ * @GO_STYLE_FILL: fill.
+ * @GO_STYLE_LINE: line.
+ * @GO_STYLE_MARKER: marker.
+ * @GO_STYLE_FONT: font.
+ * @GO_STYLE_TEXT_LAYOUT: text orientaiton.
+ * @GO_STYLE_INTERPOLATION: curve interpolation.
+ * @GO_STYLE_MARKER_NO_COLOR: marker with no color.
+ * @GO_STYLE_ALL: all elements
+ *
+ * Gives the meaningful fields in @GOStyle. Anyw combination can be used, except
+ * that @GO_STYLE_OUTLINE and @GO_STYLE_OUTLINE should never coexist.
+ **/
+
+/**
+ * GOStyleLine:
+ * @width: line width:
+ * <0 == no line,
+ * =0 == hairline : unscaled, minimum useful (can be bigger than visible) size.
+ * >0 in pts.
+ * @dash_type: #GOLineDashType.
+ * @auto_dash: automatic dash type.
+ * @color: color is used as background for compatibility
+ * (pattern == 0 means filled with background color).
+ * @fore: second color used for patterned lines.
+ * @auto_color: color is automatic.
+ * @auto_fore: fore is automatic.
+ * @pattern: pattern.
+ * @cap: cap style.
+ * @join: join style.
+ * @miter_limit: mitter limit.
+ **/
+
+/**
+ * GOStyleMark:
+ * @mark: the used #GOMarker.
+ * @auto_shape: automatic @marc.
+ * @auto_outline_color: automatic outline color.
+ * @auto_fill_color: automatic fill color.
+ **/
+
 #define HSCALE 100
 #define VSCALE 120
 
@@ -113,7 +172,7 @@ create_go_combo_color (StylePrefState *state,
 {
 	GtkWidget *w;
 
-	w = go_color_selector_new (initial_color, automatic_color, group);
+	w = go_selector_new_color (initial_color, automatic_color, group);
 	gtk_widget_set_halign (w, GTK_ALIGN_START);
 	gtk_label_set_mnemonic_widget (
 		GTK_LABEL (gtk_builder_get_object (gui, label_name)), w);
@@ -209,7 +268,7 @@ outline_init (StylePrefState *state, gboolean enable, GOEditor *editor)
 	}
 
 	/* DashType */
-	w = go_line_dash_selector_new (style->line.dash_type,
+	w = go_selector_new_line_dash (style->line.dash_type,
 				       default_style->line.dash_type);
 	gtk_widget_set_halign (w, GTK_ALIGN_START);
 	gtk_grid_attach (GTK_GRID (grid), w, 1, 0, 2, 1);
@@ -284,7 +343,7 @@ line_init (StylePrefState *state, gboolean enable, GOEditor *editor)
 	go_editor_register_widget (editor, grid);
 
 	/* DashType */
-	w = go_line_dash_selector_new (style->line.dash_type,
+	w = go_selector_new_line_dash (style->line.dash_type,
 				       default_style->line.dash_type);
 	gtk_widget_set_halign (w, GTK_ALIGN_START);
 	gtk_grid_attach (GTK_GRID (grid), w, 1, 0, 2, 1);
@@ -405,7 +464,7 @@ fill_gradient_init (StylePrefState *state)
 	GtkWidget *label;
 
 	state->fill.gradient.selector = selector =
-		go_gradient_selector_new (style->fill.gradient.dir,
+		go_selector_new_gradient (style->fill.gradient.dir,
 					  style->fill.gradient.dir);
 	go_gradient_selector_set_colors (GO_SELECTOR (selector),
 					 style->fill.pattern.back,
@@ -744,7 +803,7 @@ marker_init (StylePrefState *state, gboolean enable, GOEditor *editor, GOCmdCont
 	if (!enable)
 		return;
 
-	gui = go_gtk_builder_new_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -858,7 +917,7 @@ font_init (StylePrefState *state, guint32 enable, GOEditor *editor, GOCmdContext
 
 	g_return_if_fail (style->font.font != NULL);
 
-	gui = go_gtk_builder_new_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_load_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -1034,7 +1093,7 @@ go_style_populate_editor (GOStyle *style,
 		state->doc = NULL;
 
 	if ((enable & (GO_STYLE_OUTLINE | GO_STYLE_LINE | GO_STYLE_FILL)) != 0) {
-		gui = go_gtk_builder_new_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_load_internal ("res:go:utils/go-style-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui == NULL) {
 			g_free (state);
 			return;
@@ -1064,6 +1123,16 @@ go_style_populate_editor (GOStyle *style,
 	}
 }
 
+/**
+ * go_style_get_editor:
+ * @style: #GOStyle
+ * @default_style: the style used as default
+ * @cc: #GOCmdContext
+ * @object_with_style: the object owning the style
+ *
+ * Builds the widget used to edit the style.
+ * Returns: (transfer full): the style editor
+ **/
 gpointer
 go_style_get_editor (GOStyle *style,
 		     GOStyle *default_style,
@@ -1097,7 +1166,7 @@ go_style_new (void)
  *
  * Duplicates @style.
  *
- * return value: a new #GOStyle
+ * Returns: (transfer full): a new #GOStyle
  **/
 GOStyle *
 go_style_dup (GOStyle const *src)
@@ -1793,7 +1862,7 @@ go_style_set_marker (GOStyle *style, GOMarker *marker)
  *
  * Accessor for @style::marker, without referencing it.
  *
- * return value: the style #GOMarker.
+ * Returns: (transfer none): the style #GOMarker.
  **/
 GOMarker const *
 go_style_get_marker (GOStyle *style)
