@@ -357,7 +357,7 @@ gog_xy_plot_populate_editor (GogObject *obj,
 {
 #ifdef GOFFICE_WITH_GTK
 	GtkBuilder *gui =
-		go_gtk_builder_new ("res:go:plot_xy/gog-xy-prefs.ui",
+		go_gtk_builder_load ("res:go:plot_xy/gog-xy-prefs.ui",
 				    GETTEXT_PACKAGE, cc);
 
 	if (gui != NULL) {
@@ -580,8 +580,8 @@ gog_bubble_plot_class_init (GogPlotClass *plot_klass)
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_IN_3D,
 		g_param_spec_boolean ("in-3d",
-			_("In 3d"),
-			_("Draw 3d bubbles"),
+			_("In 3D"),
+			_("Draw 3D bubbles"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_BUBBLE_PROP_SCALE,
@@ -740,7 +740,7 @@ gog_xy_color_plot_populate_editor (GogObject *obj,
 {
 #ifdef GOFFICE_WITH_GTK
 	GtkBuilder *gui =
-		go_gtk_builder_new ("res:go:plot_xy/gog-xy-color-prefs.ui",
+		go_gtk_builder_load ("res:go:plot_xy/gog-xy-color-prefs.ui",
 				    GETTEXT_PACKAGE, cc);
 
 	if (gui != NULL) {
@@ -2092,7 +2092,7 @@ gog_xy_series_populate_editor (GogObject *obj,
 	GogXYSeries *series;
 	GtkWidget *w;
 	GtkBuilder *gui =
-		go_gtk_builder_new ("res:go:plot_xy/gog-xy-series-prefs.ui",
+		go_gtk_builder_load ("res:go:plot_xy/gog-xy-series-prefs.ui",
 				    GETTEXT_PACKAGE, cc);
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
@@ -2151,6 +2151,10 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 		GOG_SERIES_FILL_TYPE_X_ORIGIN,
 		GOG_SERIES_FILL_TYPE_SELF,
 		GOG_SERIES_FILL_TYPE_NEXT,
+		GOG_SERIES_FILL_TYPE_X_AXIS_MIN,
+		GOG_SERIES_FILL_TYPE_X_AXIS_MAX,
+		GOG_SERIES_FILL_TYPE_Y_AXIS_MIN,
+		GOG_SERIES_FILL_TYPE_Y_AXIS_MAX,
 		GOG_SERIES_FILL_TYPE_INVALID
 	};
 	GogObjectClass *gog_klass = (GogObjectClass *)gso_klass;
